
penman.models
=============

.. automodule:: penman.models

   This sub-package contains specified instances of the
   :class:`penman.model.Model` class.

   Available Models
   ----------------

   .. toctree::
      :maxdepth: 1

      penman.models.amr
      penman.models.noop
